/*-------------------------------------------------------------------------+
| Copyright 2011 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.af3.rcp.application.utils;

import static org.fortiss.af3.project.ui.utils.ImportProjectUtils.determineTargetFileLocation;
import static org.fortiss.af3.project.utils.ProjectUtils.saveProject;
import static org.fortiss.tooling.kernel.utils.EMFResourceUtils.refreshWorkspace;
import static org.fortiss.tooling.kernel.utils.LoggingUtils.error;
import static org.fortiss.tooling.kernel.utils.LoggingUtils.showError;

import java.io.IOException;

import org.eclipse.emf.common.util.URI;
import org.eclipse.ui.IPerspectiveDescriptor;
import org.eclipse.ui.IWorkbench;
import org.eclipse.ui.PlatformUI;
import org.fortiss.af3.project.example.IExample;
import org.fortiss.af3.project.model.FileProject;
import org.fortiss.af3.project.ui.perspective.ModelingPerspectiveFactory;
import org.fortiss.af3.rcp.application.AF3ApplicationActivator;

/**
 * Utility methods for dealing with the UI.
 * 
 * @author becker
 */
public class ApplicationUtils {

	/**
	 * Switch to the AF3 modeling perspective (e.g., if being in the Simulator perspective, creating
	 * a new project should result in the change to the AF3 modeling perspective).
	 */
	public static void switchToAF3Perspective() {

		IWorkbench workbench = PlatformUI.getWorkbench();
		for(IPerspectiveDescriptor pDesc : workbench.getPerspectiveRegistry().getPerspectives()) {
			if(pDesc.getLabel().equals(ModelingPerspectiveFactory.MODELING_PERSPECTIVE_NAME)) {
				if(workbench.getActiveWorkbenchWindow() != null &&
						workbench.getActiveWorkbenchWindow().getActivePage() != null) {
					workbench.getActiveWorkbenchWindow().getActivePage().setPerspective(pDesc);
				}
				break;
			}
		}
		refreshWorkspace();
	}

	/**
	 * Creates a project (per code) and stores it.
	 * 
	 * @param projectName
	 *            the name of project to create
	 * @param suffix
	 *            the current AF3 project files extension
	 * @param builder
	 *            {@link IExample} builder
	 * @return whether the created project is saved to workspace
	 */
	public static boolean createAndSaveProject(String projectName, String suffix,
			IExample builder) {
		URI projectURI = determineTargetFileLocation(projectName);
		if(projectURI != null) {
			projectName = projectURI.lastSegment().replace(suffix, "");
			FileProject project = builder.createProject(projectName);
			try {
				saveProject(project, projectURI);
			} catch(final IOException e) {
				error(AF3ApplicationActivator.getDefault(), e.getMessage(), e);
				showError(e.getMessage());
			}
		}
		return false;
	}
}
